<?php
/**
 * Gutenberg Editor CSS
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package     Soulmedic
 * @author      Soulmedic
 * @copyright   Copyright (c) 2019, Soulmedic
 * @link        http://themes-demo.com/soulmedic/
 * @since       Soulmedic 1.0
 */

if ( ! class_exists( 'Gutenberg_Editor_CSS' ) ) :
	/**
	 * Admin Helper
	 */
	class Gutenberg_Editor_CSS {

		

		function __construct() {

			//add_action( 'admin_enqueue_scripts', array( $this, 'soulmedic_backend_editor_fonts' ) );
			add_action( 'current_screen', array( $this,  'soulmedic_current_screen_hook' ), 10, 1 );
			add_action( 'enqueue_block_editor_assets', array( $this, 'soulmedic_backend_editor_styles' ), 10 );
			add_filter( 'tiny_mce_before_init', array( $this, 'soulmedic_theme_editor_dynamic_styles' ) );
		}


		function soulmedic_theme_editor_dynamic_styles( $mceInit ) {

			$styles = '';

			#Body Section
			$disable_boddy_settings = dttheme_option("appearance", "disable-boddy-settings");
			if (empty($disable_boddy_settings)) :
				$font_type = dttheme_option("appearance", "body-font-type");
				$style = dttheme_option("appearance","body-standard-font-style");

				if( !empty($font_type) ){
				#Body Font: Standard
					$body_font = dttheme_option("appearance","body-standard-font");
					
				} else {
				#Body Font: Google
					$body_font = dttheme_option("appearance", "body-font");
				}

				$body_font_size = dttheme_option("appearance", "body-font-size");
				$body_font_color = dttheme_option("appearance", "body-font-color");

				$body_primary_color = dttheme_option("appearance", "body-primary-color");
				$body_secondary_color = dttheme_option("appearance", "body-secondary-color");


				if (!empty($body_font) || (!empty($body_font_color) and $body_font_color != "#") || !empty($body_font_size)) :
					
					$styles .= "body, p {";
					if (!empty($body_font)) {	$styles .= "font-family:{$body_font} , sans-serif !important; ";  }

					if (!empty($body_font_color) && ($body_font_color != '#')) { $styles .= "color:{$body_font_color} !important; "; }

					if (!empty($body_font_size)) {	$styles .= "font-size:{$body_font_size}px !important; "; }
					
					if( !empty( $style ) ){ $styles .= "font-style: {$style} !important; ";	}
					$styles .= "}";
				endif;

				if ((!empty($body_primary_color) and $body_primary_color != "#") || (!empty($body_secondary_color) and $body_secondary_color != "#")) :
					if (!empty($body_primary_color) && ($body_primary_color != '#')) { 	$styles .= "a { color:{$body_primary_color} !important; }"; }

					if (!empty($body_secondary_color) && ($body_secondary_color != '#')) {	$styles .= "a:hover { color:{$body_secondary_color} !important; }";	}
				endif;

			endif; #Body Section End

			#Typography Settings
			$disable_typo = dttheme_option("appearance", "disable-typography-settings");
			if (empty($disable_typo)) :
				for ($i = 1; $i <= 6; $i++) :
					$font_type = dttheme_option("appearance", "H{$i}-font-type");
					$style = dttheme_option("appearance","H{$i}-standard-font-style");
					
					if( !empty($font_type) ){
					#Menu Font: Standard
						$font = dttheme_option("appearance","H{$i}-standard-font");
					} else {
					#Menu Font: Google
						$font = dttheme_option("appearance", "H{$i}-font");
					}
					
					$color = dttheme_option("appearance", "H{$i}-font-color");
					$size = dttheme_option("appearance", "H{$i}-size");

					if (!empty($font) || (!empty($color) and $color != "#") || !empty($size)) :
						$styles .= " H$i {";
						if (!empty($font)) {	$styles .= "font-family:{$font}; ";	}

						if( !empty($font_type) ){
							if (!empty($style)) { $styles .= "font-style:{$style}; "; }
						}

						if (!empty($color) && ($color != '#')) { $styles .= "color:{$color}; ";	}
						
						if (!empty($size)) { $styles .= "font-size:{$size}px; "; }

						$styles .= "}";
					endif;
				endfor;
			endif; 

			if ( isset( $mceInit['content_style'] ) ) {
				$mceInit['content_style'] .= ' ' . $styles . ' ';
			} else {
				$mceInit['content_style'] = $styles . ' ';
			}

			return $mceInit;
		}

		function soulmedic_current_screen_hook( $current_screen ) {
			
			if ( 'post' == $current_screen->base ) {

			$custom_fonts = array();
			#Body Section
			$disable_boddy_settings = dttheme_option("appearance", "disable-boddy-settings");

			if (empty($disable_boddy_settings)) :
				$font = dttheme_option("appearance", "body-font");
				$font = str_replace(" ", "+", $font);
				if (!empty($font)) :
					array_push($custom_fonts, $font);
				endif;
			endif;

			#Typography Section
			$disable_typo = dttheme_option("appearance", "disable-typography-settings");
			if (empty($disable_typo)) :
				for ($i = 1; $i <= 6; $i++) :
					$font = dttheme_option("appearance", "H{$i}-font");
					if (!empty($font)) :
						$font = str_replace(" ", "+", $font);
						array_push($custom_fonts, $font);
					endif;
				endfor;
			endif; #Typography Section End

			if (!empty($custom_fonts)) :
				$custom_fonts = array_unique($custom_fonts);
				$font = implode(":300,400,400italic,700|", $custom_fonts);
				$font .= ":300,400,400italic,700|";
			endif;
	
			$font .= "Open+Sans:300italic,400italic,600italic,700italic,800italic,400,600,700,800,300%7CRoboto+Slab:400,100,300,700%7COpen+Sans:300italic,400italic,600italic,700italic,800italic,400,300,600,700,800%7CLato:100,100i,300,300i,400,400i,700,700i,900,900i";
			$protocol = is_ssl() ? 'https' : 'http';
			$query_args = array('family' => $font, 'subset' => $subset);
			$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
		

				add_editor_style( $fonts_url );
				add_editor_style( 'css/editor-style.css' );
			}
		}

		function soulmedic_backend_editor_styles() {
			
			wp_enqueue_style( 'soulmedic-gutenberg', get_theme_file_uri('/css/admin-gutenberg.css'), false, IAMD_THEME_VERSION, 'all' );
			
			$styles = '';

			#Body Section
			$disable_boddy_settings = dttheme_option("appearance", "disable-boddy-settings");
			if (empty($disable_boddy_settings)) :
				$font_type = dttheme_option("appearance", "body-font-type");
				$style = dttheme_option("appearance","body-standard-font-style");

				if( !empty($font_type) ){
				#Body Font: Standard
					$body_font = dttheme_option("appearance","body-standard-font");
					
				} else {
				#Body Font: Google
					$body_font = dttheme_option("appearance", "body-font");
				}

				$body_font_size = dttheme_option("appearance", "body-font-size");
				$body_font_color = dttheme_option("appearance", "body-font-color");

				$body_primary_color = dttheme_option("appearance", "body-primary-color");
				$body_secondary_color = dttheme_option("appearance", "body-secondary-color");


				if (!empty($body_font) || (!empty($body_font_color) and $body_font_color != "#") || !empty($body_font_size)) :
					$styles .= ".editor-block-list__block, .editor-styles-wrapper .editor-rich-text p, .wp-block-code, .wp-block-preformatted pre, pre, .wp-block-pullquote p {";
					if (!empty($body_font)) {	$styles .= "font-family:{$body_font} , sans-serif !important; ";  }

					if (!empty($body_font_color) && ($body_font_color != '#')) { $styles .= "color:{$body_font_color} !important; "; }

					if (!empty($body_font_size)) {	$styles .= "font-size:{$body_font_size}px !important; "; }
					
					if( !empty( $style ) ){ $styles .= "font-style: {$style} !important;";	}
					$styles .= "}";
				endif;

				if ((!empty($body_primary_color) and $body_primary_color != "#") || (!empty($body_secondary_color) and $body_secondary_color != "#")) :
					if (!empty($body_primary_color) && ($body_primary_color != '#')) { 	$styles .= ".editor-styles-wrapper a { color:{$body_primary_color} !important; }"; }

					if (!empty($body_secondary_color) && ($body_secondary_color != '#')) {	$styles .= ".editor-styles-wrapper a:hover { color:{$body_secondary_color} !important; }";	}
				endif;
			endif; #Body Section End

			#Typography Settings
			$disable_typo = dttheme_option("appearance", "disable-typography-settings");
			if (empty($disable_typo)) :
				for ($i = 1; $i <= 6; $i++) :
					$font_type = dttheme_option("appearance", "H{$i}-font-type");
					$style = dttheme_option("appearance","H{$i}-standard-font-style");
					
					if( !empty($font_type) ){
					#Menu Font: Standard
						$font = dttheme_option("appearance","H{$i}-standard-font");
					} else {
					#Menu Font: Google
						$font = dttheme_option("appearance", "H{$i}-font");
					}
					
					$color = dttheme_option("appearance", "H{$i}-font-color");
					$size = dttheme_option("appearance", "H{$i}-size");

					if (!empty($font) || (!empty($color) and $color != "#") || !empty($size)) :

						if($i == 1) {
							$styles .= ".wp-block-heading H$i, .editor-styles-wrapper .editor-post-title__block .editor-post-title__input {";
						} else{
							$styles .= ".wp-block-heading H$i {";
						}

						if (!empty($font)) {	$styles .= "font-family:{$font} !important; ";	}

						if( !empty($font_type) ){
							if (!empty($style)) { $styles .= "font-style:{$style} !important; "; }
						}

						if (!empty($color) && ($color != '#')) { $styles .= "color:{$color} !important; ";	}
						
						if (!empty($size)) { $styles .= "font-size:{$size}px !important; "; }

						$styles .= "}";
					endif;
				endfor;
			endif; 
			
			wp_add_inline_style( 'soulmedic-gutenberg', $styles );
		}
	}

	new Gutenberg_Editor_CSS();

endif;